pub enum CreateEventSubscriptionError {
KMSAccessDeniedFault(String),
KMSDisabledFault(String),
KMSInvalidStateFault(String),
KMSNotFoundFault(String),
KMSThrottlingFault(String),
ResourceAlreadyExistsFault(String),
ResourceNotFoundFault(String),
ResourceQuotaExceededFault(String),
SNSInvalidTopicFault(String),
SNSNoAuthorizationFault(String),
}Expand description
Errors returned by CreateEventSubscription
Variants
KMSAccessDeniedFault(String)
The ciphertext references a key that doesn't exist or that the DMS account doesn't have access to.
KMSDisabledFault(String)
The specified master key (CMK) isn't enabled.
KMSInvalidStateFault(String)
The state of the specified AWS KMS resource isn't valid for this request.
KMSNotFoundFault(String)
The specified AWS KMS entity or resource can't be found.
KMSThrottlingFault(String)
This request triggered AWS KMS request throttling.
ResourceAlreadyExistsFault(String)
The resource you are attempting to create already exists.
ResourceNotFoundFault(String)
The resource could not be found.
ResourceQuotaExceededFault(String)
The quota for this resource quota has been exceeded.
SNSInvalidTopicFault(String)
The SNS topic is invalid.
SNSNoAuthorizationFault(String)
You are not authorized for the SNS subscription.
Implementations