pub struct DescribeReplicationTaskAssessmentRunsMessage {
pub filters: Option<Vec<Filter>>,
pub marker: Option<String>,
pub max_records: Option<i64>,
}Expand description
Fields
filters: Option<Vec<Filter>>Filters applied to the premigration assessment runs described in the form of key-value pairs.
Valid filter names: replication-task-assessment-run-arn, replication-task-arn, replication-instance-arn, status
marker: Option<String>An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
max_records: Option<i64>The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.