pub struct CreateReplicationInstanceMessage {Show 14 fields
pub allocated_storage: Option<i64>,
pub auto_minor_version_upgrade: Option<bool>,
pub availability_zone: Option<String>,
pub dns_name_servers: Option<String>,
pub engine_version: Option<String>,
pub kms_key_id: Option<String>,
pub multi_az: Option<bool>,
pub preferred_maintenance_window: Option<String>,
pub publicly_accessible: Option<bool>,
pub replication_instance_class: String,
pub replication_instance_identifier: String,
pub replication_subnet_group_identifier: Option<String>,
pub tags: Option<Vec<Tag>>,
pub vpc_security_group_ids: Option<Vec<String>>,
}Expand description
Fields
allocated_storage: Option<i64>The amount of storage (in gigabytes) to be initially allocated for the replication instance.
auto_minor_version_upgrade: Option<bool>A value that indicates whether minor engine upgrades are applied automatically to the replication instance during the maintenance window. This parameter defaults to true.
Default: true
availability_zone: Option<String>The Availability Zone where the replication instance will be created. The default value is a random, system-chosen Availability Zone in the endpoint's AWS Region, for example: us-east-1d
dns_name_servers: Option<String>A list of custom DNS name servers supported for the replication instance to access your on-premise source or target database. This list overrides the default name servers supported by the replication instance. You can specify a comma-separated list of internet addresses for up to four on-premise DNS name servers. For example: "1.1.1.1,2.2.2.2,3.3.3.3,4.4.4.4"
engine_version: Option<String>The engine version number of the replication instance.
kms_key_id: Option<String>An AWS KMS key identifier that is used to encrypt the data on the replication instance.
If you don't specify a value for the KmsKeyId parameter, then AWS DMS uses your default encryption key.
AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS Region.
multi_az: Option<bool> Specifies whether the replication instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the Multi-AZ parameter is set to true.
preferred_maintenance_window: Option<String>The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
Format: ddd:hh24:mi-ddd:hh24:mi
Default: A 30-minute window selected at random from an 8-hour block of time per AWS Region, occurring on a random day of the week.
Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun
Constraints: Minimum 30-minute window.
publicly_accessible: Option<bool> Specifies the accessibility options for the replication instance. A value of true represents an instance with a public IP address. A value of false represents an instance with a private IP address. The default value is true.
replication_instance_class: StringThe compute and memory capacity of the replication instance as defined for the specified replication instance class. For example to specify the instance class dms.c4.large, set this parameter to "dms.c4.large".
For more information on the settings and capacities for the available replication instance classes, see Selecting the right AWS DMS replication instance for your migration.
replication_instance_identifier: StringThe replication instance identifier. This parameter is stored as a lowercase string.
Constraints:
-
Must contain 1-63 alphanumeric characters or hyphens.
-
First character must be a letter.
-
Can't end with a hyphen or contain two consecutive hyphens.
Example: myrepinstance
replication_subnet_group_identifier: Option<String>A subnet group to associate with the replication instance.
One or more tags to be assigned to the replication instance.
vpc_security_group_ids: Option<Vec<String>>Specifies the VPC security group to be used with the replication instance. The VPC security group must work with the VPC containing the replication instance.